@@ -473,7 +473,9 @@ class XRedisAsync(Singleton):
     
     async def zadd(self, z_name, member, val):
         conn = await self._get_connection()
-        return await conn.zadd(z_name, val, member)
+        return await conn.zadd(z_name, {
+            member: val
+        })
     
     async def zrem(self, z_name, member):
         conn = await self._get_connection()
